//import '@babel/polyfill';

// // 隐藏预加载动画
// if (document.getElementById('preloader')) {
//   document.getElementById('preloader').style.display = 'none';
// }

// Vue
import { getCurrentInstance } from 'vue';
import App from './App.vue';

// 设置
import setting from './setting';

// 混合
import mixinApp from './mixins/app';
import mixinPage from './mixins/page';

// store
import store from './store';

// ViewUIPlus
import ViewUIPlus from 'view-ui-plus';

// 菜单
import menuHeader from './menu/header';
//import menuSider from './menu/sider';

// 多语言
import i18n from './i18n';

// 路由工厂
import router, { initRouter } from './router';

// API
import modelApi from './api/model';
import customModelApi from './api/customModel';
import dataSourceApi from './api/dataSource';
import taskApi from './api/task';
import applicationApi from './api/application';

// 使用样式，修改主题可以在 styles 目录下创建新的主题包并修改 iView 默认的 less 变量
// 参考 https://www.iviewui.com/docs/guide/theme
import './styles/index.less';
//import './libs/iview-pro/iview-pro.css';

// 默认css
import './styles/css/default.css';

// CKEditor
//import ckEditor from 'ckeditor4-vue';

// 指令
import focus from './directive/focus';
import tabHide from './directive/tabHide';

// 基础布局
import basicLayout from './layouts/basic-layout/index.vue';

// libs
import lodop from './libs/lodop';
import * as echarts from 'echarts';
import request from './libs/request';
import util from './libs/util';

const install = function (app) {
  if (install.installed) return;

  app.use(router);
  app.use(store);
  app.use(i18n);
  app.use(ViewUIPlus);
  //app.use(plugins);

  app.mixin(mixinApp);
  //Vue.use(ckEditor);

  // 组件
  // Object.keys(components).forEach(key => {
  //   app.component(key, components[key]);
  // });

  // 指令，自动获得焦点
  app.directive('focus', focus);
  // 指令，隐藏Tab标签，保留内容
  app.directive('tab-hide', tabHide);

  // eCharts图表
  app.config.globalProperties.$echarts = echarts;
};

// auto install
// if (typeof window !== 'undefined' && window.Vue) {
//     install(window.Vue);
// }

const API = {
  //version: import.meta.env.VERSION,
  // locale: locale.use,
  // i18n: locale.i18n,
  install
  //...components
};

// 页面
const files = import.meta.glob('./pages/**/*.vue', { eager: true });
const pages = {};

Object.keys(files).forEach(key => {
  pages[key.replace(/(\.\/pages\/)/g, '')] = files[key].default;
});

// 基础组件
const componentFiles = import.meta.glob('./components/**/*.vue', { eager: true });
const components = {};

Object.keys(componentFiles).forEach(key => {
  components[
    key
      .replace(/(\.\/pages\/)/g, '')
      .split('/')
      .pop()
      .split('.')[0]
  ] = componentFiles[key].default;
});

const created = async (app, routes, files, componentFiles) => {
  app.use(API);

  if (window) {
    // 将根实例存全局，可在特殊场景下调用
    window.$app = getCurrentInstance();
    window.$app.$t = i18n.global.t;
    window.$app.$Message = app.config.globalProperties.$Message;
    window.$app.$Notice = app.config.globalProperties.$Notice;
  }

  // 覆盖组件
  if (componentFiles) {
    Object.keys(componentFiles).forEach(key => {
      components[
        key
          .replace(/(\.\/pages\/)/g, '')
          .split('/')
          .pop()
          .split('.')[0]
      ] = componentFiles[key].default;
    });
  }

  // 注册组件
  Object.keys(components).forEach(key => {
    app.component(key, components[key]);
  });

  // 页面
  Object.keys(files).forEach(key => {
    pages[key.replace(/(\.\/pages\/)/g, '')] = files[key].default;
  });

  // 初始化路由
  initRouter(pages, routes);
  // 加载多语言
  store.dispatch('admin/i18n/load', app);
  // 设置顶栏菜单
  store.commit('admin/menu/setHeader', menuHeader);
  // 加载用户登录的数据
  store.dispatch('admin/account/load');
  // 加载边栏菜单
  //store.dispatch('admin/menu/loadSider');
  // // 初始化全屏监听
  // store.dispatch('admin/layout/listenFullscreen');

  // 所有页面
  app.config.globalProperties.$pages = pages;
};

export default API;

export {
  pages,
  components,
  App,
  store,
  i18n,
  setting,
  basicLayout,
  lodop,
  request,
  mixinPage,
  modelApi,
  customModelApi,
  dataSourceApi,
  taskApi,
  applicationApi,
  util,
  router,
  initRouter,
  created
};
