import permissionApi from '../api/permission';
import Setting from '../setting';

// 动态路由
export default {
  async init(router, pages) {
    let res = await permissionApi.queryRouter();

    // 根路由
    const root = router.getRoutes().find(item => item.path == '/');

    res.forEach(item => {
      if (item.isCustomPage) {
        // 自定义页面数据处理
        item.url += '?id=' + item.customPageID;
        if (item.customPage.customPageTemplate) {
          item.templateUrl = 'template/' + item.customPage.customPageTemplate.substr(0, 1).toLowerCase() + item.customPage.customPageTemplate.substr(1) + '.vue';
        }
      }

      if (!!(item.templateUrl || '').trim()) {
        // 路由地址，不含参数
        const path = item.url?.split('?')[0] || '';
        // 路由名称
        const name = path.replace(/\//g, '-');
        // 参数
        const data = {};
        if (item.url && item.url.split('?').length > 1) {
          item.url
            .split('?')[1]
            .split('&')
            .forEach(item => {
              if (item.split('=').length > 1 && item.split('=')[0].length > 0) {
                data[item.split('=')[0]] = item.split('=')[1];
              }
            });
        }

        root.children.push({
          path,
          name,
          meta: {
            title: getNameI18n(item),
            description: getDescI18n(item),
            data,
            auth: true,
            cache: true
          },
          component: () => {
            return new Promise(resolve => {
              resolve(pages[item.templateUrl]);
            });
          }
        });
      }
    });

    router.removeRoute('root');
    router.addRoute(root);

    // 404
    router.addRoute({
      path: '/:pathMatch(.*)',
      name: '404',
      meta: {
        title: '404'
      },
      component: () => {
        return new Promise(resolve => {
          resolve(pages['system/error/404.vue']);
        });
      }
    });
  }
};

// 获取多语言名称
function getNameI18n(item) {
  if (Setting.layout.showI18n) {
    let key = 'Permission_' + item.url.split('?')[0];
    let text = window.$app.$t(key);
    if (text == key) {
      return item.name;
    } else {
      return text;
    }
  } else {
    return item.name;
  }
}

// 获取多语言描述
function getDescI18n(item) {
  if (Setting.layout.showI18n) {
    let key = 'Permission_' + item.url.split('?')[0] + '_SubName';
    let text = window.$app.$t(key);
    if (text == key) {
      return item.subName;
    } else {
      return text;
    }
  } else {
    return item.subName;
  }
}
