import { createRouter, createWebHistory, createWebHashHistory, createMemoryHistory } from 'vue-router';
import ViewUIPlus from 'view-ui-plus';
import util from '../libs/util';
import Setting from '../setting';
import store from '../store/index';
import dynamic from './dynamic';

const base = window.$base || import.meta.env.VITE_APP_BASE_PATH;

const router = createRouter({
  history: Setting.routerMode === 'history' ? createWebHistory(base) : Setting.routerMode === 'hash' ? createWebHashHistory(base) : createMemoryHistory(base),
  routes: []
});

// 是否初始化
let inited = false;

// 创建路由
const initRouter = (pages, routes) => {
  // 添加静态路由
  routes.forEach(route => {
    router.addRoute(route);
  });

  /**
   * 路由拦截
   * 权限验证
   */
  router.beforeEach(async (to, from, next) => {
    if (Setting.showProgressBar) {
      ViewUIPlus.LoadingBar.start();
    }

    // 监听路由 控制侧边栏显示 标记当前顶栏菜单（如需要）
    store.dispatch('admin/menu/setMenuList', to);

    if (!inited) {
      // 初始化动态路由
      await dynamic.init(router, pages);

      // 处理路由 得到每一级的路由设置
      store.commit('admin/page/init', router.getRoutes());
      // 持久化数据加载上次退出时的多页列表
      store.dispatch('admin/page/openedLoad', { loadOpenedTabs: true }, { root: true });

      inited = true;
      next({
        ...to,
        replace: true
      });
    } else {
      // 判断权限
      if (to.matched.some(item => item.meta.auth)) {
        // 需要校验权限
        const token = util.cookies.get('token');

        if (token && token !== 'undefined') {
          const permissions = store.getters['admin/menu/permission'];

          if (permissions[to.fullPath.substring(1)] || permissions[to.fullPath.split('?')[0].substring(1)]) {
            // 权限验证通过
            next();
          } else {
            // 权限验证不通过，跳转首页
            next({
              name: 'home'
            });
          }
        } else {
          // 没有token，跳转登录页
          next({
            name: 'login',
            query: {
              redirect: to.fullPath
            }
          });
        }
      } else {
        // 不需要身份校验 直接通过
        next();
      }
    }
  });

  router.afterEach(to => {
    if (Setting.showProgressBar) ViewUIPlus.LoadingBar.finish();
    // 多页控制 打开新的页面
    if (setting.layout.tabs) {
      store.dispatch('admin/page/open', to);
    }

    // 更改标题
    window.document.title = window.$app.$t(to.meta.title) + ' - ' + Setting.info.title;

    // 返回页面顶端
    window.scrollTo(0, 0);
  });
};

export { initRouter };

export default router;
