import { assign, defaultsDeep } from 'lodash';

/**
 * 默认配置
 * */

//const basePath = import.meta.env.VITE_APP_BASE_PATH;

const Setting = {
  /**
   * 基础配置
   * */
  // 基本信息
  info: {},
  // 项目的 ID
  appID: 'app',
  // 根目录
  //rootPath: basePath == '' || basePath == null ? '/static/' : '/' + basePath + '/static/',
  // 网页标题的后缀，不需要设置为 false 或空
  titleSuffix: 'Admin Plus',
  // 路由模式，可选值为 history 或 hash
  routerMode: 'history',
  // 页面切换时，是否显示模拟的进度条
  showProgressBar: true,
  // Cookies 默认保存时间，单位：天
  cookiesExpires: 1,
  /**
   * 多语言配置
   * */
  i18n: {
    // 默认语言
    default: 'zh-CN',
    // 是否根据用户电脑配置自动设置语言（仅第一次有效）
    auto: false,
    // 切换语言时是否刷新页面
    refresh: false
  },
  /**
   * 打印控件
   * */
  lodop: {
    // 名称
    name: '南京摩赫信息技术有限公司',
    // key
    key: '58C4DF8932E17DEBE409D1E7F683CAFE'
  },
  /**
   * 布局配置
   * */
  // 侧边菜单宽度，单位 px，不可动态修改，需与 setting.less 的 @menuSideWidth 保持一致
  menuSideWidth: 256,
  // 顶栏高度，单位 px，不可动态修改，需与 setting.less 的 @headerHeight 保持一致
  headerHeight: 64,
  // 侧边菜单折起时的宽度，单位 px，不可动态修改，需与 setting.less 的 @menuSideCollapseWidth 保持一致
  menuSideCollapseWidth: 80,
  layout: {
    // 侧边栏风格，可选值为 dark 或 light
    siderTheme: 'dark',
    // 顶栏风格，可选值为 light、dark 或 primary
    headerTheme: 'light',
    // 顶栏是否置顶，开启后会覆盖侧边栏，需开启 headerFix
    headerStick: false,
    // 是否开启多 Tabs 页签
    tabs: false,
    // 多 Tabs 页签是否显示图标，开启 tabs 时有效
    showTabsIcon: true,
    // 是否固定多 Tabs 多页签
    tabsFix: true,
    // 再次点击 Tabs 页签时，是否重载当前页面
    tabsReload: false,
    // 页签是否支持拖拽排序
    tabsOrder: true,
    // 是否固定侧边栏
    siderFix: true,
    // 是否固定顶栏
    headerFix: true,
    // 是否在下滑时隐藏顶栏，需开启 headerFix，如果开启了 tabsFix，Tabs 也会被隐藏
    headerHide: true,
    // 是否显示顶部菜单栏
    // 一般来说，侧边的菜单栏足以满足大部分业务，如需动态切换侧边栏，可开启此选项启用顶部一级菜单，此时侧边栏将作为二级菜单
    headerMenu: false,
    // 侧边菜单栏是否开启手风琴模式
    menuAccordion: true,
    // 是否显示折叠侧边栏按钮，移动端下会自动强制开启
    showSiderCollapse: true,
    // 侧边菜单栏是否默认折起
    menuCollapse: false,
    // 再次点击当前侧边菜单时，是否重载当前页面
    menuSiderReload: false,
    // 再次点击当前顶部菜单时，是否重载当前页面
    menuHeaderReload: false,
    // 菜单筛选
    menuFilter: false,
    // 侧边菜单折起时，是否在子菜单前显示父级菜单名称
    showCollapseMenuTitle: false,
    // 是否显示重载按钮
    showReload: false,
    // 是否显示搜索
    showSearch: false,
    // 是否显示通知
    showNotice: false,
    // 是否显示全屏
    showFullscreen: true,
    // 在手机访问时，是否在顶部显示小尺寸 logo
    showMobileLogo: true,
    // 是否显示全局面包屑，开启 headerMenu 时不可用
    showBreadcrumb: true,
    // 全局面包屑是否显示图标，开启 showBreadcrumb 时有效
    showBreadcrumbIcon: false,
    // 是否显示日志入口，开启与否，不影响日志记录，如不希望用户看到可关闭
    showLog: false,
    // 是否显示多语言
    showI18n: false,
    // 是否支持动态修改布局配置，移动端下会自动强制关闭
    enableSetting: false,
    // 退出登录时，是否二次确认
    logoutConfirm: true,
    // 是否根据操作系统缩放比例，自动调整比例
    autoFixRatio: true,
    // 是否允许点击遮罩层关闭
    maskClosable: true,
    // 是否允许拖动
    draggable: true,
    // 提示框样式(SweetAlert/Message/Notice)
    alertStyle: 'SweetAlert',
    // 筛选标题栏宽度
    filterWidth: 125,
    // 每页默认数量
    pageSize: 10
  },
  /**
   * 多页 Tabs
   * */
  page: {
    // 默认打开的页签
    opened: [],
    // 登录时是否加载上次打开的页签
    loadOpenedTabs: true
  },
  // /**
  //  * 徽标配置
  //  * */
  // badge: {
  //   // 侧边菜单徽标
  //   siderMenuBadge: [
  //     {
  //       path: '/dashboard/monitor',
  //       count: 1
  //     },
  //     {
  //       path: '/system',
  //       text: 'New',
  //       type: 'warning'
  //     },
  //     {
  //       path: '/list',
  //       color: 'cyan'
  //     },
  //     {
  //       path: '/list/table-list',
  //       color: 'cyan'
  //     }
  //   ],
  //   // 顶栏菜单徽标
  //   headerMenuBadge: []
  // },
  /**
   * 水印配置
   * */
  waterMark: {
    // 是否显示
    show: false,
    // 初始显示文案，可以通过 vuex 随时更新
    text: 'MOOHO',
    // 水印配置
    options: {}
  },
  /**
   * 功能配置
   * */
  // 相同路由，不同参数间进行切换，是否强力更新
  sameRouteForceUpdate: false,
  // 富文本编辑器
  editorUrl: 'https://cdn-source.ckeditor.com/4.21.0/full-all/ckeditor.js'
};

// const copyTo = (source, target) => {
//   for (let key in source) {
//     if (typeof source[key] === 'object') {
//       if (target[key] == null) {
//         target[key] = {};
//       }
//       copyTo(source[key], target[key]);
//     } else {
//       target[key] = source[key];
//     }
//   }
// };

let localSetting = window.setting;

if (localSetting) {
  defaultsDeep(localSetting, Setting);
  assign(Setting, localSetting);

  //copyTo(localSetting, Setting);
}

export default Setting;
