import { defineConfig } from 'vite';
import vue from '@vitejs/plugin-vue';
import { resolve } from 'path';
import Setting from './test/setting.env';

const build = defineConfig({
  define: {
    __VUE_OPTIONS_API__: true,
    __VUE_PROD_DEVTOOLS__: false,
    __VUE_PROD_HYDRATION_MISMATCH_DETAILS__: false
  },
  plugins: [vue()],
  base: Setting.publicPath,
  build: {
    sourcemap: false, // 输出.map文件
    outDir: Setting.outputDir,
    assetsDir: Setting.assetsDir
    // minify: 'terser', // 混淆器，terser构建后文件体积更小
  },
  resolve: {
    alias: {
      '@': resolve(__dirname, '.', 'src')
    }
    // extensions: ['.js', '.json', '.vue']
  }
});

const lib = defineConfig({
  plugins: [vue()],
  publicDir: '',
  base: Setting.publicPath,
  build: {
    sourcemap: false, // 输出.map文件
    outDir: 'package',
    assetsDir: Setting.assetsDir,
    // minify: 'terser', // 混淆器，terser构建后文件体积更小
    lib: {
      entry: resolve(__dirname, './src/index.js'),
      name: 'rz666BaseAdminPlus'
    },
    rollupOptions: {
      context: 'globalThis',
      preserveEntrySignatures: 'strict',
      external: ['vue', 'view-ui-plus'],
      output: [
        {
          name: 'rz666-base-admin-plus',
          format: 'umd',
          exports: 'named',
          sourcemap: false,
          entryFileNames: 'rz666-base-admin-plus.min.js',
          chunkFileNames: '[name].js',
          assetFileNames: '[name].[ext]',
          namespaceToStringTag: true,
          inlineDynamicImports: false,
          manualChunks: undefined,
          globals: { vue: 'Vue', 'view-ui-plus': 'viewUiPlus' }
        },
        {
          name: 'rz666-base-admin-plus',
          format: 'es',
          exports: 'named',
          sourcemap: false,
          entryFileNames: 'rz666-base-admin-plus.min.esm.js',
          chunkFileNames: '[name].js',
          assetFileNames: '[name].[ext]',
          namespaceToStringTag: true,
          inlineDynamicImports: false,
          manualChunks: undefined,
          globals: { vue: 'Vue', 'view-ui-plus': 'viewUiPlus' }
        }
      ]
    }
  },
  resolve: {
    alias: {
      '@': resolve(__dirname, '.', 'src')
    }
    // extensions: ['.js', '.json', '.vue']
  }
});

export default ({ mode }) => {
  switch (mode) {
    case 'lib': // 打包库文件
      return lib;

    default: // 开发模式、生产模式
      return build;
  }
};
